@@ -46,17 +46,16 @@ typedef enum {
 
 enum {
   TARGET_URI_LIST,
-  TARGET_URL,
-  TARGET_COLOR,
-  TARGET_BGIMAGE,
-  TARGET_BACKGROUND_RESET
+  TARGET_BGIMAGE
 };
 
-static GtkTargetEntry drop_types[] = {
+static const GtkTargetEntry drop_types[] = {
   {"text/uri-list", 0, TARGET_URI_LIST},
-  /*  { "application/x-color", 0, TARGET_COLOR }, */
-  { "property/bgimage", 0, TARGET_BGIMAGE },
-  /*  { "x-special/gnome-reset-background", 0, TARGET_BACKGROUND_RESET }*/
+  { "property/bgimage", 0, TARGET_BGIMAGE }
+};
+
+static const GtkTargetEntry drag_types[] = {
+  {"text/uri-list", GTK_TARGET_OTHER_WIDGET, TARGET_URI_LIST}
 };
 
 static void
@@ -402,24 +401,19 @@ wp_color_changed (AppearanceData *data,
   if (item == NULL)
     return;
 
-  g_free (item->pri_color);
-
   gtk_color_button_get_color (GTK_COLOR_BUTTON (data->wp_pcpicker), item->pcolor);
-
-  item->pri_color = gdk_color_to_string (item->pcolor);
-
-  g_free (item->sec_color);
-
   gtk_color_button_get_color (GTK_COLOR_BUTTON (data->wp_scpicker), item->scolor);
 
-  item->sec_color = gdk_color_to_string (item->scolor);
-
   if (update)
   {
-    gconf_client_set_string (data->client, WP_PCOLOR_KEY,
-                             item->pri_color, NULL);
-    gconf_client_set_string (data->client, WP_SCOLOR_KEY,
-                             item->sec_color, NULL);
+    gchar *pcolor, *scolor;
+
+    pcolor = gdk_color_to_string (item->pcolor);
+    scolor = gdk_color_to_string (item->scolor);
+    gconf_client_set_string (data->client, WP_PCOLOR_KEY, pcolor, NULL);
+    gconf_client_set_string (data->client, WP_SCOLOR_KEY, scolor, NULL);
+    g_free (pcolor);
+    g_free (scolor);
   }
 
   wp_shade_type_changed (NULL, data);
@@ -584,6 +578,7 @@ static gboolean
 wp_props_wp_set (AppearanceData *data, GnomeWPItem *item)
 {
   GConfChangeSet *cs;
+  gchar *pcolor, *scolor;
 
   cs = gconf_change_set_new ();
 
@@ -601,16 +596,24 @@ wp_props_wp_set (AppearanceData *data, GnomeWPItem *item)
     else
       uri = g_filename_to_utf8 (item->filename, -1, NULL, NULL, NULL);
 
-    gconf_change_set_set_string (cs, WP_FILE_KEY, uri);
-    g_free (uri);
+    if (uri == NULL) {
+      g_warning ("Failed to convert filename to UTF-8: %s\n", item->filename);
+    } else {
+      gconf_change_set_set_string (cs, WP_FILE_KEY, uri);
+      g_free (uri);
+    }
 
     gconf_change_set_set_string (cs, WP_OPTIONS_KEY, item->options);
   }
 
   gconf_change_set_set_string (cs, WP_SHADING_KEY, item->shade_type);
 
-  gconf_change_set_set_string (cs, WP_PCOLOR_KEY, item->pri_color);
-  gconf_change_set_set_string (cs, WP_SCOLOR_KEY, item->sec_color);
+  pcolor = gdk_color_to_string (item->pcolor);
+  scolor = gdk_color_to_string (item->scolor);
+  gconf_change_set_set_string (cs, WP_PCOLOR_KEY, pcolor);
+  gconf_change_set_set_string (cs, WP_SCOLOR_KEY, scolor);
+  g_free (pcolor);
+  g_free (scolor);
 
   gconf_client_commit_change_set (data->client, cs, TRUE, NULL);
 
@@ -669,14 +672,13 @@ wp_file_open_dialog (GtkWidget *widget,
 }
 
 static void
-wp_dragged_image (GtkWidget *widget,
+wp_drag_received (GtkWidget *widget,
                   GdkDragContext *context,
                   gint x, gint y,
                   GtkSelectionData *selection_data,
                   guint info, guint time,
                   AppearanceData *data)
 {
-
   if (info == TARGET_URI_LIST || info == TARGET_BGIMAGE)
   {
     GList * uris;
@@ -709,6 +711,23 @@ wp_dragged_image (GtkWidget *widget,
   }
 }
 
+static void
+wp_drag_get_data (GtkWidget *widget,
+		  GdkDragContext *context,
+		  GtkSelectionData *selection_data,
+		  guint type, guint time,
+		  AppearanceData *data)
+{
+  if (type == TARGET_URI_LIST) {
+    GnomeWPItem *item = get_selected_item (data, NULL);
+
+    if (item != NULL) {
+      gchar *uris[] = { item->filename, NULL };
+      gtk_selection_data_set_uris (selection_data, uris);
+    }
+  }
+}
+
 static gboolean
 wp_view_tooltip_cb (GtkWidget  *widget,
                     gint x,
@@ -996,7 +1015,12 @@ desktop_init (AppearanceData *data,
   gtk_drag_dest_set (GTK_WIDGET (data->wp_view), GTK_DEST_DEFAULT_ALL, drop_types,
                      G_N_ELEMENTS (drop_types), GDK_ACTION_COPY | GDK_ACTION_MOVE);
   g_signal_connect (data->wp_view, "drag_data_received",
-                    (GCallback) wp_dragged_image, data);
+                    (GCallback) wp_drag_received, data);
+
+  gtk_drag_source_set (GTK_WIDGET (data->wp_view), GDK_BUTTON1_MASK,
+                       drag_types, G_N_ELEMENTS (drag_types), GDK_ACTION_COPY);
+  g_signal_connect (data->wp_view, "drag-data-get",
+		    (GCallback) wp_drag_get_data, data);
 
   data->wp_style_menu = glade_xml_get_widget (data->xml, "wp_style_menu");
 
