@@ -241,7 +241,7 @@ web_combo_changed_cb (GtkComboBox *combo, GnomeDACapplet *capplet)
     gtk_widget_set_sensitive (capplet->new_win_radiobutton, has_net_remote);
     gtk_widget_set_sensitive (capplet->new_tab_radiobutton, has_net_remote);
 
-    gtk_editable_set_editable (GTK_EDITABLE (capplet->web_browser_command_entry), is_custom_active);
+    gtk_widget_set_sensitive (capplet->web_browser_command_entry, is_custom_active);
     gtk_widget_set_sensitive (capplet->web_browser_command_label, is_custom_active);
     gtk_widget_set_sensitive (capplet->web_browser_terminal_checkbutton, is_custom_active);
 }
@@ -293,7 +293,7 @@ mail_combo_changed_cb (GtkComboBox *combo, GnomeDACapplet *capplet)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (capplet->mail_reader_terminal_checkbutton),
 				  gconf_client_get_bool (capplet->gconf, DEFAULT_APPS_KEY_MAILER_NEEDS_TERM, NULL));
 
-    gtk_editable_set_editable (GTK_EDITABLE (capplet->mail_reader_command_entry), is_custom_active);
+    gtk_widget_set_sensitive (capplet->mail_reader_command_entry, is_custom_active);
     gtk_widget_set_sensitive (capplet->mail_reader_command_label, is_custom_active);
     gtk_widget_set_sensitive (capplet->mail_reader_terminal_checkbutton, is_custom_active);
 }
@@ -344,7 +344,7 @@ media_combo_changed_cb (GtkComboBox *combo, GnomeDACapplet *capplet)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (capplet->media_player_terminal_checkbutton),
 				  gconf_client_get_bool (capplet->gconf, DEFAULT_APPS_KEY_MEDIA_NEEDS_TERM, NULL));
 
-    gtk_editable_set_editable (GTK_EDITABLE (capplet->media_player_command_entry), is_custom_active);
+    gtk_widget_set_sensitive (capplet->media_player_command_entry, is_custom_active);
     gtk_widget_set_sensitive (capplet->media_player_command_label, is_custom_active);
     gtk_widget_set_sensitive (capplet->media_player_terminal_checkbutton, is_custom_active);
 }
@@ -396,9 +396,9 @@ terminal_combo_changed_cb (GtkComboBox *combo, GnomeDACapplet *capplet)
     g_free (terminal_cmd);
     g_free (terminal_cmd_arg);
 
-    gtk_editable_set_editable (GTK_EDITABLE (capplet->terminal_command_entry), is_custom_active);
+    gtk_widget_set_sensitive (capplet->terminal_command_entry, is_custom_active);
     gtk_widget_set_sensitive (capplet->terminal_command_label, is_custom_active);
-    gtk_editable_set_editable (GTK_EDITABLE (capplet->terminal_exec_flag_entry), is_custom_active);
+    gtk_widget_set_sensitive (capplet->terminal_exec_flag_entry, is_custom_active);
     gtk_widget_set_sensitive (capplet->terminal_exec_flag_label, is_custom_active);
 }
 
@@ -447,7 +447,7 @@ visual_combo_changed_cb (GtkComboBox *combo, GnomeDACapplet *capplet)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (capplet->visual_startup_checkbutton),
 				  gconf_client_get_bool (capplet->gconf, DEFAULT_APPS_KEY_VISUAL_STARTUP, NULL));
 
-    gtk_editable_set_editable (GTK_EDITABLE (capplet->visual_command_entry), is_custom_active);
+    gtk_widget_set_sensitive (capplet->visual_command_entry, is_custom_active);
     gtk_widget_set_sensitive (capplet->visual_command_label, is_custom_active);
 
 }
@@ -497,7 +497,7 @@ mobility_combo_changed_cb (GtkComboBox *combo, GnomeDACapplet *capplet)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (capplet->mobility_startup_checkbutton),
 				  gconf_client_get_bool (capplet->gconf, DEFAULT_APPS_KEY_MOBILITY_STARTUP, NULL));
 
-    gtk_editable_set_editable (GTK_EDITABLE (capplet->mobility_command_entry), is_custom_active);
+    gtk_widget_set_sensitive (capplet->mobility_command_entry, is_custom_active);
     gtk_widget_set_sensitive (capplet->mobility_command_label, is_custom_active);
 }
 
@@ -533,8 +533,8 @@ static struct {
     const gchar *icon;
 } icons[] = {
     { "web_browser_image", "web-browser"      },
-    { "mail_reader_image", "stock_mail-open"  },
-    { "media_player_image", "gnome-audio"     },
+    { "mail_reader_image", "emblem-mail"  },
+    { "media_player_image", "applications-multimedia"     },
     { "visual_image",      "zoom-best-fit" },
     { "mobility_image",    "preferences-desktop-accessibility" },
 /*    { "messenger_image",   "im"               },
@@ -628,7 +628,7 @@ web_browser_update_combo_box (GnomeDACapplet *capplet, const gchar *command)
     /* TODO: Remove when GConfPropertyEditor will be used */
     gtk_entry_set_text (GTK_ENTRY (capplet->web_browser_command_entry), command);
 
-    gtk_editable_set_editable (GTK_EDITABLE (capplet->web_browser_command_entry), is_custom_active);
+    gtk_widget_set_sensitive (capplet->web_browser_command_entry, is_custom_active);
     gtk_widget_set_sensitive (capplet->web_browser_command_label, is_custom_active);
     gtk_widget_set_sensitive (capplet->web_browser_terminal_checkbutton, is_custom_active);
 
@@ -704,7 +704,7 @@ mail_reader_update_combo_box (GnomeDACapplet *capplet, const gchar *command)
 
     gtk_entry_set_text (GTK_ENTRY (capplet->mail_reader_command_entry), command);
 
-    gtk_editable_set_editable (GTK_EDITABLE (capplet->mail_reader_command_entry), is_custom_active);
+    gtk_widget_set_sensitive (capplet->mail_reader_command_entry, is_custom_active);
     gtk_widget_set_sensitive (capplet->mail_reader_command_label, is_custom_active);
     gtk_widget_set_sensitive (capplet->mail_reader_terminal_checkbutton, is_custom_active);
 
@@ -733,7 +733,7 @@ media_player_update_combo_box (GnomeDACapplet *capplet, const gchar *command)
 
     gtk_entry_set_text (GTK_ENTRY (capplet->media_player_command_entry), command);
 
-    gtk_editable_set_editable (GTK_EDITABLE (capplet->media_player_command_entry), is_custom_active);
+    gtk_widget_set_sensitive (capplet->media_player_command_entry, is_custom_active);
     gtk_widget_set_sensitive (capplet->media_player_command_label, is_custom_active);
     gtk_widget_set_sensitive (capplet->media_player_terminal_checkbutton, is_custom_active);
 
@@ -762,9 +762,9 @@ terminal_update_combo_box (GnomeDACapplet *capplet, const gchar *command)
 
     gtk_entry_set_text (GTK_ENTRY (capplet->terminal_command_entry), command);
 
-    gtk_editable_set_editable (GTK_EDITABLE (capplet->terminal_command_entry), is_custom_active);
+    gtk_widget_set_sensitive (capplet->terminal_command_entry, is_custom_active);
     gtk_widget_set_sensitive (capplet->terminal_command_label, is_custom_active);
-    gtk_editable_set_editable (GTK_EDITABLE (capplet->terminal_exec_flag_entry), is_custom_active);
+    gtk_widget_set_sensitive (capplet->terminal_exec_flag_entry, is_custom_active);
     gtk_widget_set_sensitive (capplet->terminal_exec_flag_label, is_custom_active);
 
     if (gtk_combo_box_get_active (GTK_COMBO_BOX (capplet->term_combo_box)) != index)
@@ -792,7 +792,7 @@ visual_update_combo_box (GnomeDACapplet *capplet, const gchar *command)
 
     gtk_entry_set_text (GTK_ENTRY (capplet->visual_command_entry), command);
 
-    gtk_editable_set_editable (GTK_EDITABLE (capplet->visual_command_entry), is_custom_active);
+    gtk_widget_set_sensitive (capplet->visual_command_entry, is_custom_active);
     gtk_widget_set_sensitive (capplet->visual_command_label, is_custom_active);
 
     if (gtk_combo_box_get_active (GTK_COMBO_BOX (capplet->visual_combo_box)) != index)
@@ -821,7 +821,7 @@ mobility_update_combo_box (GnomeDACapplet *capplet, const gchar *command)
 
     gtk_entry_set_text (GTK_ENTRY (capplet->mobility_command_entry), command);
 
-    gtk_editable_set_editable (GTK_EDITABLE (capplet->mobility_command_entry), is_custom_active);
+    gtk_widget_set_sensitive (capplet->mobility_command_entry, is_custom_active);
     gtk_widget_set_sensitive (capplet->mobility_command_label, is_custom_active);
 
     if (gtk_combo_box_get_active (GTK_COMBO_BOX (capplet->mobility_combo_box)) != index)
